<?php

use App\Models\Language;
use App\Models\LanguagePhrase;
use App\Services\LanguageService;
use Illuminate\Database\Seeder;

class LanguagePhraseTableSeederV1000 extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        $this->insertLangPhrases(1, $this->getEnglishLangPhrases());

        $this->insertLangPhrases(2, $this->getGermanLangPhrases());

        $this->insertLangPhrases(3, $this->getFrenchLangPhrases());
    }

    public function getEnglishLangPhrases()
    {
        return [
            'cart' => [
                'coupon' => [
                    'coupon_code' => "Coupon code",
                    'discount' => 'Discount',
                    'required' => 'Valid Coupon code is required.',
                    'invalid' => 'Coupon code is invalid.',
                    'valid_from' => 'This Coupon code is valid from :date.',
                    'expired' => 'Coupon is expired.',
                    'not_valid_for' => 'The Coupon is not valid for this product.',
                    'already_used' => 'You have already used this coupon.',
                    'usage_limit_exceed' => 'Coupon usage limit has exceeded.',
                    'have_coupon' => 'Have a coupon code?'
                ]
            ],
            'order' => [
                'coupon_info' => 'Coupon Info',
                'coupon_code' => 'Coupon Code',
                'coupon_amount' => 'Coupon Amount'
            ]
        ];
    }

    public function getGermanLangPhrases()
    {
        return [
            'cart' => [
                'coupon' => [
                    'coupon_code' => "Gutscheincode",
                    'discount' => 'Rabatt',
                    'required' => 'Ein gültiger Gutscheincode ist erforderlich.',
                    'invalid' => 'Gutscheincode ist ungültig.',
                    'valid_from' => 'Dieser Gutscheincode ist gültig ab :date.',
                    'expired' => 'Gutschein ist abgelaufen.',
                    'not_valid_for' => 'Der Gutschein gilt nicht für dieses Produkt.',
                    'already_used' => 'Sie haben diesen Gutschein bereits verwendet.',
                    'usage_limit_exceed' => 'Das Nutzungslimit für Gutscheine wurde überschritten.',
                    'have_coupon' => 'Haben sie einen Gutscheincode?'
                ]
            ],
            'order' => [
                'coupon_info' => 'Gutscheininfo',
                'coupon_code' => 'Gutscheincode',
                'coupon_amount' => 'Gutscheinbetrag'
            ]
        ];
    }

    public function getFrenchLangPhrases()
    {
        return [
            'cart' => [
                'coupon' => [
                    'coupon_code' => "Code de coupon",
                    'discount' => 'Remise',
                    'required' => 'Un code de coupon valide est requis.',
                    'invalid' => 'Le code du coupon n\'est pas valide.',
                    'valid_from' => 'Ce code de coupon est valide à partir de :date.',
                    'expired' => 'Le coupon est expiré.',
                    'not_valid_for' => 'Le coupon n\'est pas valable pour ce produit.',
                    'already_used' => 'Vous avez déjà utilisé ce coupon.',
                    'usage_limit_exceed' => 'La limite d\'utilisation du coupon a été dépassée.',
                    'have_coupon' => 'Vous avez un code promo?'
                ]
            ],
            'order' => [
                'coupon_info' => 'Informations sur le coupon',
                'coupon_code' => 'Code de coupon',
                'coupon_amount' => 'Montant du coupon'
            ]
        ];
    }

    public function insertLangPhrases($lang_id, $lang_phrases)
    {
        foreach ($lang_phrases as $group => $key_phrases) {
            $key_dot_phrases = Arr::dot($key_phrases);

            $service = new LanguageService(new Language(), new LanguagePhrase());

            $service->updateTranslations($lang_id, $group, $key_dot_phrases);
        }
    }
}
